/*
 Arduino Thermometer
  Gepubliceerd op 18 november 2015
  Conrad Electronic Benelux B.V.
  http://www.conrad.nl

 Benodigde onderdelen:
  1 Rode LED
  1 Groene LED
  1 Blauwe LED
  2 Weerstanden 150 Ohm
  1 Weerstand 100 Ohm
  1 Temperatuursensor LM35
  8 Draadbruggen
  1 Breadboard

 Dit project is onderdeel van de Conrad Arduino Starterkit.
*/

// Benoem de elementen die je in deze sketch wilt gebruiken
const int rodeLed = 2;                                // De rode LED is aangesloten op pin 2
const int groeneLed = 3;                              // De groene LED is aangesloten op pin 3
const int blauweLed = 4;                              // De blauwe LED is aangesloten op pin 4
const int sensor = A0;                                // De sensor is aangesloten op pin A0
const float basisTemperatuur = 20.0;                  // De normale temperatuur bedraagt 20.0 graden

// Hier geven we eenmalig aan wat de instellingen voor deze sketch moeten zijn
void setup() {
  Serial.begin(9600);                                    // Opent een verbinding met de computer, zo kunnen we data uitlezen via de Serial Monitor
  for(int pinNumber = 2; pinNumber <5; pinNumber++){     // De pinnen 2 tot en met 4 dienen als output in de sketch, bij het begin van de sketch staan ze uit (deze schrijfwijze noem je een 'for loop').
    pinMode(pinNumber,OUTPUT);
    digitalWrite(pinNumber, LOW);
  }
 }

// Hier geven we aan welke stappen de Arduino moet afwerken in de sketch
void loop() {
  int sensorWaarde = analogRead(sensor);              // De Sensorwaarde geeft aan welke waarde de sensor registreert (0-1024)
  Serial.print("Sensorwaarde: ");                     // Toont de Sensorwaarde op de computer. Deze gebruik je enkel voor debugging
  Serial.print(sensorWaarde);
  Serial.print(" | ");

  float voltage = (sensorWaarde/1024.0) *5.0;         // De sensor meet in een bereik van 0-1024, via deze formule reken je dit om in een bepaalde spanning (volt)
  Serial.print("Volt: ");                             // Toont het berekende voltage op de computer. Deze gebruik je enkel voor debugging
  Serial.print(voltage);
  Serial.print(" | ");

  float temperatuur = voltage * 100;                  // De sensor geeft een spanning van 10 mV per 1 graden Celsius.
  Serial.print("graden Celcius: ");                   // Toont de gemeten temperatuur op de computer
  Serial.println(temperatuur);

  if(temperatuur < basisTemperatuur-2){               // Schept een voorwaarde; als de temperatuur lager is dan 18 graden (2 graden onder de basistemperatuur)
    digitalWrite(blauweLed, HIGH);                    // De blauwe LED gaat aan en 1/2 seconde later weer uit (deze knippert dus blauw)
    delay(500);  
    digitalWrite(blauweLed, LOW);                       
    digitalWrite(groeneLed, LOW);                     // Alle andere LED's zijn uit
    digitalWrite(rodeLed, LOW);
 }
 else if(temperatuur >= basisTemperatuur-2 && temperatuur < basisTemperatuur){     // Schept een voorwaarde; tussen 18 graden en 20 graden
    digitalWrite(blauweLed, HIGH);                                                  // De blauwe LED gaat aan
    digitalWrite(groeneLed, LOW);                                                   // Alle andere LED's zijn uit
    digitalWrite(rodeLed, LOW);
 }
 else if(temperatuur >= basisTemperatuur && temperatuur < basisTemperatuur+2){      // Schept een voorwaarde; tussen 20 graden en 22 graden
    digitalWrite(rodeLed, LOW);                             
    digitalWrite(groeneLed, HIGH);                                                  // De groene LED gaat aan
    digitalWrite(blauweLed, LOW);
 }
 else if(temperatuur >= basisTemperatuur+2 && temperatuur < basisTemperatuur+4){    // Schept een voorwaarde; tussen 22 graden en 24 graden
    digitalWrite(rodeLed, HIGH);                                                    // De rode LED gaat aan 
    digitalWrite(groeneLed, LOW);
    digitalWrite(blauweLed, LOW);                                                  
 }
 else if(temperatuur > basisTemperatuur+4){           // Schept een voorwaarde; boven de 24 graden
    digitalWrite(blauweLed, LOW);
    digitalWrite(groeneLed, LOW);
    digitalWrite(rodeLed, HIGH);                      // De rode LED gaat aan en 1/2 seconde later weer uit (deze knippert dus rood)
    delay(500);
    digitalWrite(rodeLed, LOW);
 }
delay(500);                                          // Het programma pauzeert 500 milliseconden (1/2 seconde) en begint daarna opnieuw. Dit voorkomt foute waarden op de sensor.
}
